@@ -446,8 +446,8 @@ class KiwixStorage:
             if error_code == 404:
                 return False
 
-        for key, value in meta.items():
-            if value is not None and remote.get(key) != value:
+        for mkey, mvalue in meta.items():
+            if mvalue is not None and remote.get(mkey) != mvalue:
                 return False
         return True
 
@@ -481,7 +481,7 @@ class KiwixStorage:
 
     def delete_object(self, key, bucket_name=None, **kwargs):
         bucket_name = self._bucket_name_param(bucket_name)
-        return self.get_object(key=key, bucket=bucket_name).delete(**kwargs)
+        return self.get_object(key=key, bucket_name=bucket_name).delete(**kwargs)
 
     def allow_public_downloads_on(self, bucket_name=None):
         """sets policy on bucket to allow anyone to GET objects (downloads)
@@ -598,6 +598,7 @@ class KiwixStorage:
         if not self.is_wasabi:
             raise NotImplementedError("Only Wasabi feature")
 
+        bucket_name = self._bucket_name_param(bucket_name)
         url = f"{self.wasabi_url}/{bucket_name}"
         if key is not None:
             url += f"/{key}"
